SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci ;
CREATE SCHEMA IF NOT EXISTS `setbook` DEFAULT CHARACTER SET latin1 ;
USE `mydb` ;

-- -----------------------------------------------------
-- Table `mydb`.`Log`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `mydb`.`Log` ;

CREATE  TABLE IF NOT EXISTS `mydb`.`Log` (
  `idLOG` INT NOT NULL ,
  `TimeStamp` DATETIME NULL ,
  `Type` VARCHAR(64) NULL ,
  `Message` VARCHAR(256) NULL ,
  PRIMARY KEY (`idLOG`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

USE `setbook` ;

-- -----------------------------------------------------
-- Table `setbook`.`users`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `setbook`.`users` ;

CREATE  TABLE IF NOT EXISTS `setbook`.`users` (
  `UserID` INT(11) NOT NULL AUTO_INCREMENT ,
  `Email_Address` VARCHAR(255) NOT NULL ,
  `FirstName` VARCHAR(255) NULL DEFAULT NULL ,
  `LastName` VARCHAR(255) NULL DEFAULT NULL ,
  `Password` VARCHAR(512) NULL DEFAULT NULL ,
  `Date_Of_Birth` DATE NULL DEFAULT NULL ,
  `Date_Joined` DATE NULL DEFAULT NULL ,
  `Suspended` TINYINT(1)  NULL DEFAULT FALSE ,
  `DisplayPostHours` INT(11) NULL ,
  PRIMARY KEY (`UserID`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `setbook`.`admin`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `setbook`.`admin` ;

CREATE  TABLE IF NOT EXISTS `setbook`.`admin` (
  `UserID` INT(11) NOT NULL ,
  `Admin Level` INT(11) NOT NULL ,
  CONSTRAINT `UserID`
    FOREIGN KEY (`UserID` )
    REFERENCES `setbook`.`users` (`UserID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE INDEX `UserID` ON `setbook`.`admin` (`UserID` ASC) ;


-- -----------------------------------------------------
-- Table `setbook`.`posts`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `setbook`.`posts` ;

CREATE  TABLE IF NOT EXISTS `setbook`.`posts` (
  `PostsID` INT(11) NOT NULL AUTO_INCREMENT ,
  `Title` VARCHAR(255) NULL DEFAULT NULL ,
  `Date_Posted` DATETIME NOT NULL ,
  `Text` TEXT NULL DEFAULT NULL ,
  `Poster` INT(11) NOT NULL ,
  `Parent_Post` INT(11) NOT NULL ,
  `TargetID` INT(11) NOT NULL ,
  PRIMARY KEY (`PostsID`) ,
  CONSTRAINT `Poster`
    FOREIGN KEY (`Poster` )
    REFERENCES `setbook`.`users` (`UserID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE INDEX `Poster` ON `setbook`.`posts` (`Poster` ASC) ;


-- -----------------------------------------------------
-- Table `setbook`.`user_friends`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `setbook`.`user_friends` ;

CREATE  TABLE IF NOT EXISTS `setbook`.`user_friends` (
  `User_Friends_id` INT(11) NOT NULL AUTO_INCREMENT ,
  `User` INT(11) NOT NULL ,
  `Friend` INT(11) NOT NULL ,
  `Date_Added` DATETIME NOT NULL ,
  PRIMARY KEY (`User_Friends_id`) ,
  CONSTRAINT `Friend`
    FOREIGN KEY (`Friend` )
    REFERENCES `setbook`.`users` (`UserID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `User`
    FOREIGN KEY (`User` )
    REFERENCES `setbook`.`users` (`UserID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE INDEX `User` ON `setbook`.`user_friends` (`User` ASC) ;

CREATE INDEX `Friend` ON `setbook`.`user_friends` (`Friend` ASC) ;


-- -----------------------------------------------------
-- Table `setbook`.`user_likes`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `setbook`.`user_likes` ;

CREATE  TABLE IF NOT EXISTS `setbook`.`user_likes` (
  `User_Likes_ID` INT(11) NOT NULL AUTO_INCREMENT ,
  `UserID` INT(11) NOT NULL ,
  `PostID` INT(11) NOT NULL ,
  `Like` BINARY(1) NULL DEFAULT NULL ,
  `Date` DATETIME NULL DEFAULT NULL ,
  PRIMARY KEY (`User_Likes_ID`) ,
  CONSTRAINT `Post`
    FOREIGN KEY (`PostID` )
    REFERENCES `setbook`.`posts` (`PostsID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_user_likes_users1`
    FOREIGN KEY (`UserID` )
    REFERENCES `setbook`.`users` (`UserID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE INDEX `likes` ON `setbook`.`user_likes` (`PostID` ASC) ;

CREATE INDEX `Post` ON `setbook`.`user_likes` (`PostID` ASC) ;

CREATE INDEX `fk_user_likes_users1` ON `setbook`.`user_likes` (`UserID` ASC) ;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
